@@ -208,7 +208,7 @@ impl Value for CmdOpt {
     /// Can't change the default value of [`NonOpt`](crate::opt::NonOpt)
     fn set_default_value(&mut self, _value: OptValue) {}
 
-    fn parse_value(&self, _string: Ustr) -> Result<OptValue> {
+    fn parse_value(&self, _string: Ustr, _disable: bool, _index: u64) -> Result<OptValue> {
         Ok(OptValue::from(true))
     }
 
@@ -343,7 +343,7 @@ mod test {
         assert_eq!(cmd.get_value().is_null(), true);
         assert_eq!(cmd.get_default_value().is_null(), true);
         assert_eq!(cmd.has_value(), false);
-        let value = cmd.parse_value("".into());
+        let value = cmd.parse_value("".into(), false, 0);
         assert_eq!(value.is_ok(), true);
         let value = value.unwrap();
         assert_eq!(value.is_bool(), true);
