@@ -243,7 +243,7 @@ impl Value for ArrayOpt {
         self.default_value = value;
     }
 
-    fn parse_value(&self, string: Ustr) -> Result<OptValue> {
+    fn parse_value(&self, string: Ustr, _disable: bool, _index: u64) -> Result<OptValue> {
         Ok(OptValue::from(vec![string.to_string()]))
     }
 
